@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailsem.c,v 1.10 2005/12/16 02:19:15 hoa Exp $
+ * $Id: mailsem.c,v 1.11 2006/05/22 13:39:40 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailsem.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -41,10 +45,6 @@
 #include <fcntl.h>
 #include <unistd.h>
 
-#ifndef CONFIG_H
-#include "config.h"
-#endif
-
 #ifdef LIBETPAN_REENTRANT
 #include <pthread.h>
 #include <semaphore.h>
@@ -52,10 +52,10 @@
 
 struct mailsem_internal {
   /* Current count of the semaphore. */
-  u_int count;
+  unsigned int count;
   
   /* Number of threads that have called <sema_wait>. */
-  u_long waiters_count;
+  unsigned long waiters_count;
   
 #ifdef LIBETPAN_REENTRANT
   /* Serialize access to <count> and <waiters_count>. */
@@ -67,7 +67,7 @@ struct mailsem_internal {
 };
 
 static int mailsem_internal_init(struct mailsem_internal * s,
-    u_int initial_count)
+    unsigned int initial_count)
 {
 #ifdef LIBETPAN_REENTRANT
   int r;
@@ -180,7 +180,7 @@ static int mailsem_internal_post(struct mailsem_internal * s)
 enum {
   SEMKIND_SEMOPEN,
   SEMKIND_SEMINIT,
-  SEMKIND_INTERNAL,
+  SEMKIND_INTERNAL
 };
 
 #if 0
