@@ -30,9 +30,17 @@
  */
 
 /*
- * $Id: mailstream.c,v 1.19 2006/12/22 18:45:44 hoa Exp $
+ * $Id: mailstream.c,v 1.23 2008/02/17 13:13:26 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
+#ifdef WIN32
+#	include "win_etpan.h"
+#endif
+
 #include "mailstream.h"
 #include "maillock.h"
 #include <string.h>
@@ -82,7 +90,7 @@ static size_t write_to_internal_buffer(mailstream * s,
   return count;
 }
 
-static size_t write_direct(mailstream * s, const void * buf, size_t count)
+static ssize_t write_direct(mailstream * s, const void * buf, size_t count)
 {
   size_t left;
   const char * cur_buf;
@@ -93,7 +101,7 @@ static size_t write_direct(mailstream * s, const void * buf, size_t count)
   while (left > 0) {
     written = mailstream_low_write(s->low, cur_buf, left);
 
-    if (written == -1) {
+    if (written < 0) {
       if (count == left)
 	return -1;
       else
@@ -140,7 +148,7 @@ int mailstream_flush(mailstream * s)
   while (left > 0) {
     written = mailstream_low_write(s->low, cur_buf, left);
 
-    if (written == -1)
+    if (written < 0)
       goto move_buffer;
     cur_buf += written;
     left -=  written;
@@ -184,7 +192,7 @@ static ssize_t read_through_buffer(mailstream * s, void * buf, size_t count)
   while (left > 0) {
     bytes_read = mailstream_low_read(s->low, cur_buf, left);
 
-    if (bytes_read == -1) {
+    if (bytes_read < 0) {
       if (count == left)
 	return -1;
       else
@@ -236,7 +244,7 @@ ssize_t mailstream_read(mailstream * s, void * buf, size_t count)
   }
 
   read_bytes = mailstream_low_read(s->low, s->read_buffer, s->buffer_max_size);
-  if (read_bytes == -1) {
+  if (read_bytes < 0) {
     if (left == count)
       return -1;
     else {
@@ -288,7 +296,7 @@ ssize_t mailstream_feed_read_buffer(mailstream * s)
   if (s->read_buffer_len == 0) {
     read_bytes = mailstream_low_read(s->low, s->read_buffer,
 				     s->buffer_max_size);
-    if (read_bytes == -1)
+    if (read_bytes < 0)
       return -1;
     s->read_buffer_len += read_bytes;
   }
