@@ -30,9 +30,13 @@
  */
 
 /*
- * $Id: mailstream_low.c,v 1.18 2006/12/22 18:45:44 hoa Exp $
+ * $Id: mailstream_low.c,v 1.19 2007/10/27 10:08:24 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "mailstream_low.h"
 #include <stdlib.h>
 
@@ -48,7 +52,7 @@
 #	include <unistd.h>
 #endif
 #include "maillock.h"
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
