@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailstream_ssl.c,v 1.68 2008/10/05 14:30:38 colinleroy Exp $
+ * $Id: mailstream_ssl.c,v 1.71 2009/06/12 07:28:38 colinleroy Exp $
  */
 
 /*
@@ -460,7 +460,7 @@ static struct mailstream_ssl_data * ssl_data_new(int fd, void (* callback)(struc
   gnutls_cipher_set_priority (session, cipher_prio);
   gnutls_kx_set_priority (session, kx_prio);
   gnutls_mac_set_priority (session, mac_prio);
-
+  gnutls_record_disable_padding(session);
   gnutls_dh_set_prime_bits(session, 512);
 
   gnutls_transport_set_ptr(session, (gnutls_transport_ptr) fd);
@@ -719,7 +719,12 @@ static ssize_t mailstream_low_ssl_read(mailstream_low * s,
     switch (r) {
     case 0: /* closed connection */
       return -1;
-      
+    
+    case GNUTLS_E_REHANDSHAKE:
+      do {
+         r = gnutls_handshake(ssl_data->session); 
+      } while (r == GNUTLS_E_AGAIN || r == GNUTLS_E_INTERRUPTED);
+      break; /* re-receive */
     case GNUTLS_E_AGAIN:
     case GNUTLS_E_INTERRUPTED:
       r = wait_read(s);
