@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: dbdriver.c,v 1.11 2006/10/24 21:57:51 hoa Exp $
+ * $Id: dbdriver.c,v 1.13 2008/02/20 22:35:47 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -91,7 +91,6 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_db_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "db",
 
   /* sess_initialize */ initialize,
@@ -134,53 +133,7 @@ static mailsession_driver local_db_session_driver = {
   /* sess_get_messages_list */ get_messages_list,
   /* sess_get_envelopes_list */ get_envelopes_list,
   /* sess_remove_message */ NULL,
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "db",
-
-  .sess_initialize = initialize,
-  .sess_uninitialize = uninitialize,
-
-  .sess_parameters = NULL,
-
-  .sess_connect_stream = NULL,
-  .sess_connect_path = connect_path,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = NULL,
-  .sess_expunge_folder = expunge_folder,
-  .sess_status_folder = status_folder,
-  .sess_messages_number = messages_number,
-  .sess_recent_number = recent_number,
-  .sess_unseen_number = unseen_number,
-  .sess_list_folders = NULL,
-  .sess_lsub_folders = NULL,
-  .sess_subscribe_folder = NULL,
-  .sess_unsubscribe_folder = NULL,
-
-  .sess_append_message = append_message,
-  .sess_append_message_flags = append_message_flags,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = get_messages_list,
-  .sess_get_envelopes_list = get_envelopes_list,
-  .sess_remove_message = NULL,
-
-  .sess_get_message = get_message,
-  .sess_get_message_by_uid = get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * db_session_driver = &local_db_session_driver;
@@ -268,8 +221,6 @@ static int db_get_next_validity(struct mail_cache_db * maildb,
       &serialized, &serialized_len);
   
   if (r >= 0) {
-    size_t cur_token;
-    
     if (mmap_string_append_len(mmapstr, serialized, serialized_len) == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto err;
@@ -335,8 +286,6 @@ static int db_get_next_msg_number(struct mail_cache_db * maildb,
       &serialized, &serialized_len);
   
   if (r >= 0) {
-    size_t cur_token;
-    
     if (mmap_string_append_len(mmapstr, serialized, serialized_len) == NULL) {
       res = MAIL_ERROR_MEMORY;
       goto err;
@@ -722,7 +671,6 @@ static int status_folder(mailsession * session, const char * mb,
   for(i = 0 ; i < carray_count(msglist) ; i ++) {
     uint32_t num;
     uint32_t * msg;
-    int r;
     struct mail_flags * flags;
     
     msg = carray_get(msglist, i);
@@ -870,8 +818,6 @@ static int append_message_flags(mailsession * session,
   /* free msglist */
   
   for(i = 0 ; i < carray_count(msglist) ; i ++) {
-    uint32_t * msg;
-    
     msg = carray_get(msglist, i);
     free(msg);
   }
@@ -946,8 +892,6 @@ static int append_message_flags(mailsession * session,
   
  free_msglist:
   for(i = 0 ; i < carray_count(msglist) ; i ++) {
-    uint32_t * msg;
-    
     msg = carray_get(msglist, i);
     free(msg);
   }
