@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: feeddriver.c,v 1.2 2008/02/17 13:13:26 hoa Exp $
+ * $Id: feeddriver.c,v 1.3 2008/04/11 07:33:08 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -331,6 +331,258 @@ feeddriver_get_envelopes_list(mailsession * session,
   return MAIL_NO_ERROR;
 }
 
+static inline int to_be_quoted(const char * word, size_t size)
+{
+  int do_quote;
+  const char * cur;
+  size_t i;
+
+  do_quote = 0;
+  cur = word;
+  for(i = 0 ; i < size ; i ++) {
+    switch (* cur) {
+    case ',':
+    case ':':
+    case '!':
+    case '"':
+    case '#':
+    case '$':
+    case '@':
+    case '[':
+    case '\\':
+    case ']':
+    case '^':
+    case '`':
+    case '{':
+    case '|':
+    case '}':
+    case '~':
+    case '=':
+    case '?':
+    case '_':
+      do_quote = 1;
+      break;
+    default:
+      if (((unsigned char) * cur) >= 128)
+        do_quote = 1;
+      break;
+    }
+    cur ++;
+  }
+
+  return do_quote;
+}
+
+#define MAX_IMF_LINE 72
+
+static inline int quote_word(const char * display_charset,
+    MMAPString * mmapstr, const char * word, size_t size)
+{
+  const char * cur;
+  size_t i;
+  char hex[4];
+  int col;
+  
+  if (mmap_string_append(mmapstr, "=?") == NULL)
+    return -1;
+  if (mmap_string_append(mmapstr, display_charset) == NULL)
+    return -1;
+  if (mmap_string_append(mmapstr, "?Q?") == NULL)
+    return -1;
+  
+  col = mmapstr->len;
+  
+  cur = word;
+  for(i = 0 ; i < size ; i ++) {
+    int do_quote_char;
+
+    if (col + 2 /* size of "?=" */
+        + 3 /* max size of newly added character */
+        + 1 /* minimum column of string in a
+               folded header */ >= MAX_IMF_LINE) {
+      int old_pos;
+      /* adds a concatened encoded word */
+      
+      if (mmap_string_append(mmapstr, "?=") == NULL)
+        return -1;
+      
+      if (mmap_string_append(mmapstr, " ") == NULL)
+        return -1;
+      
+      old_pos = mmapstr->len;
+      
+      if (mmap_string_append(mmapstr, "=?") == NULL)
+        return -1;
+      if (mmap_string_append(mmapstr, display_charset) == NULL)
+        return -1;
+      if (mmap_string_append(mmapstr, "?Q?") == NULL)
+        return -1;
+      
+      col = mmapstr->len - old_pos;
+    }
+    
+    do_quote_char = 0;
+    switch (* cur) {
+    case ',':
+    case ':':
+    case '!':
+    case '"':
+    case '#':
+    case '$':
+    case '@':
+    case '[':
+    case '\\':
+    case ']':
+    case '^':
+    case '`':
+    case '{':
+    case '|':
+    case '}':
+    case '~':
+    case '=':
+    case '?':
+    case '_':
+      do_quote_char = 1;
+      break;
+
+    default:
+      if (((unsigned char) * cur) >= 128)
+        do_quote_char = 1;
+      break;
+    }
+
+    if (do_quote_char) {
+      snprintf(hex, 4, "=%2.2X", (unsigned char) * cur);
+      if (mmap_string_append(mmapstr, hex) == NULL)
+        return -1;
+      col += 3;
+    }
+    else {
+      if (* cur == ' ') {
+        if (mmap_string_append_c(mmapstr, '_') == NULL)
+          return -1;
+      }
+      else {
+        if (mmap_string_append_c(mmapstr, * cur) == NULL)
+          return -1;
+      }
+      col += 3;
+    }
+    cur ++;
+  }
+
+  if (mmap_string_append(mmapstr, "?=") == NULL)
+    return -1;
+  
+  return 0;
+}
+
+static inline void get_word(const char * begin,
+    const char ** pend, int * pto_be_quoted)
+{
+  const char * cur;
+  
+  cur = begin;
+
+  while ((* cur != ' ') && (* cur != '\t') && (* cur != '\0')) {
+    cur ++;
+  }
+
+  if (cur - begin +
+      1  /* minimum column of string in a
+            folded header */ > MAX_IMF_LINE)
+    * pto_be_quoted = 1;
+  else
+    * pto_be_quoted = to_be_quoted(begin, cur - begin);
+  
+  * pend = cur;
+}
+
+static char * make_quoted_printable(const char * display_charset,
+    const char * phrase)
+{
+  char * str;
+  const char * cur;
+  MMAPString * mmapstr;
+  int r;
+
+  mmapstr = mmap_string_new("");
+  if (mmapstr == NULL)
+    return NULL;
+  
+  cur = phrase;
+  while (* cur != '\0') {
+    const char * begin;
+    const char * end;
+    int do_quote;
+    int quote_words;
+
+    begin = cur;
+    end = begin;
+    quote_words = 0;
+    do_quote = 1;
+
+    while (* cur != '\0') {
+      get_word(cur, &cur, &do_quote);
+      if (do_quote) {
+        quote_words = 1;
+        end = cur;
+      }
+      else
+        break;
+      if (* cur != '\0')
+        cur ++;
+    }
+
+    if (quote_words) {
+      r = quote_word(display_charset, mmapstr, begin, end - begin);
+      if (r < 0) {
+        mmap_string_free(mmapstr);
+        return NULL;
+      }
+      
+      if ((* end == ' ') || (* end == '\t')) {
+        if (mmap_string_append_c(mmapstr, * end) == NULL) {
+          mmap_string_free(mmapstr);
+          return NULL;
+        }
+        end ++;
+      }
+
+      if (* end != '\0') {
+        if (mmap_string_append_len(mmapstr, end, cur - end) == NULL) {
+          mmap_string_free(mmapstr);
+          return NULL;
+        }
+      }
+    }
+    else {
+      if (mmap_string_append_len(mmapstr, begin, cur - begin) == NULL) {
+        mmap_string_free(mmapstr);
+        return NULL;
+      }
+    }
+
+    if ((* cur == ' ') || (* cur == '\t')) {
+      if (mmap_string_append_c(mmapstr, * cur) == 0) {
+        mmap_string_free(mmapstr);
+        return NULL;
+      }
+      cur ++;
+    }
+  }
+
+  str = strdup(mmapstr->str);
+  if (str == NULL) {
+    mmap_string_free(mmapstr);
+    return NULL;
+  }
+
+  mmap_string_free(mmapstr);
+  
+  return str;
+}
+
 static mailmessage * feed_item_to_message(mailsession * session,
     unsigned int num,
     struct newsfeed_item * item)
@@ -396,7 +648,7 @@ static mailmessage * feed_item_to_message(mailsession * session,
   subject = NULL;
   subject_const = newsfeed_item_get_title(item);
   if (subject_const != NULL) {
-    subject = strdup(subject_const);
+    subject = make_quoted_printable("utf-8", subject_const);
     if (subject == NULL) {
       goto free_date;
     }
