@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver.c,v 1.56 2006/12/26 13:13:23 hoa Exp $
+ * $Id: imapdriver.c,v 1.57 2007/08/08 21:33:30 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,6 +41,7 @@
 
 #include "mail.h"
 #include "imapdriver_tools.h"
+#include "imapdriver_tools_private.h"
 #include "mailmessage.h"
 #include "imapdriver_message.h"
 #include "imapdriver_types.h"
@@ -929,7 +930,7 @@ imapdriver_get_envelopes_list(mailsession * session,
     return MAIL_NO_ERROR;
   }
 
-  r = msg_list_to_imap_set(msg_list, &set);
+  r = imap_msg_list_to_imap_set(msg_list, &set);
   if (r != MAIL_NO_ERROR) {
     clist_foreach(msg_list, (clist_func) free, NULL);
     clist_free(msg_list);
