@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: imapdriver_tools.c,v 1.30 2008/02/20 22:15:50 hoa Exp $
+ * $Id: imapdriver_tools.c,v 1.31 2008/03/16 13:39:34 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -2466,9 +2466,32 @@ imap_fetch_result_to_envelop_list(clist * fetch_result,
   clistiter * cur;
   int r;
   unsigned int i;
-
-  i = 0;
-
+  chash * msg_hash;
+  int res;
+  
+  msg_hash = chash_new(CHASH_DEFAULTSIZE, CHASH_COPYKEY);
+  if (msg_hash == NULL) {
+    res = MAIL_ERROR_MEMORY;
+    goto err;
+  }
+  
+  for(i = 0 ; i < carray_count(env_list->msg_tab) ; i ++) {
+    chashdatum key;
+    chashdatum value;
+    mailmessage * msg;
+    
+    msg = carray_get(env_list->msg_tab, i);
+    key.data = &msg->msg_index;
+    key.len = sizeof(msg->msg_index);
+    value.data = msg;
+    value.len = 0;
+    r = chash_set(msg_hash, &key, &value, NULL);
+    if (r < 0) {
+      res = MAIL_ERROR_MEMORY;
+      goto free_hash;
+    }
+  }
+  
   for(cur = clist_begin(fetch_result) ; cur != NULL ;
       cur = clist_next(cur)) {
     struct mailimap_msg_att * msg_att;
@@ -2487,42 +2510,46 @@ imap_fetch_result_to_envelop_list(clist * fetch_result,
 
     if (r == MAIL_NO_ERROR) {
       if (uid != 0) {
-	while (i < carray_count(env_list->msg_tab)) {
+        chashdatum key;
+        chashdatum value;
+        
+        key.data = &uid;
+        key.len = sizeof(uid);
+        r = chash_get(msg_hash, &key, &value);
+        if (r == 0) {
 	  mailmessage * msg;
-	  
-	  msg = carray_get(env_list->msg_tab, i);
-	  
-	  if (uid == msg->msg_index) {
+          
+          msg = value.data;
+          if (imap_envelope != NULL) {
 	    struct mailimf_fields * fields;
+            
+            r = imap_env_to_fields(imap_envelope,
+                references, ref_size, &fields);
+            if (r == MAIL_NO_ERROR) {
+              msg->msg_fields = fields;
+            }
+          }
+          if (att_dyn != NULL) {
 	    struct mail_flags * flags;
-	    
-	    if (imap_envelope != NULL) {
-	      r = imap_env_to_fields(imap_envelope,
-				     references, ref_size, &fields);
-	      if (r == MAIL_NO_ERROR) {
-		msg->msg_fields = fields;
-	      }
-	    }
-	  
-	    if (att_dyn != NULL) {
-	      r = imap_flags_to_flags(att_dyn, &flags);
-	      
-	      if (r == MAIL_NO_ERROR) {
-		msg->msg_flags = flags;
-	      }
-	    }
-	    
-	    i ++;
-	    break;
-	  }
-	  
-	  i ++;
-	}
+            
+            r = imap_flags_to_flags(att_dyn, &flags);
+            if (r == MAIL_NO_ERROR) {
+              msg->msg_flags = flags;
+            }
+          }
+        }
       }
     }
   }
-
+  
+  chash_free(msg_hash);
+  
   return MAIL_NO_ERROR;
+  
+ free_hash:
+  chash_free(msg_hash);
+ err:
+  return res;
 }
 
 
