@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: maildirdriver.c,v 1.15 2006/06/28 06:13:47 skunk Exp $
+ * $Id: maildirdriver.c,v 1.17 2008/02/17 13:13:26 hoa Exp $
  */
 
 
@@ -47,7 +47,7 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <dirent.h>
@@ -108,9 +108,6 @@ static int get_message_by_uid(mailsession * session,
     const char * uid, mailmessage ** result);
 
 static mailsession_driver local_maildir_session_driver = {
-
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
-	
    /* sess_name */ "maildir",
 
   /* sess_initialize */ initialize,
@@ -156,57 +153,7 @@ static mailsession_driver local_maildir_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "maildir",
-
-  .sess_initialize = initialize,
-  .sess_uninitialize = uninitialize,
-
-  .sess_parameters = NULL,
-
-  .sess_connect_stream = NULL,
-  .sess_connect_path = connect_path,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = NULL,
-  .sess_expunge_folder = expunge_folder,
-  .sess_status_folder = status_folder,
-  .sess_messages_number = messages_number,
-  .sess_recent_number = recent_number,
-  .sess_unseen_number = unseen_number,
-  .sess_list_folders = NULL,
-  .sess_lsub_folders = NULL,
-  .sess_subscribe_folder = NULL,
-  .sess_unsubscribe_folder = NULL,
-
-  .sess_append_message = append_message,
-  .sess_append_message_flags = append_message_flags,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = get_messages_list,
-  .sess_get_envelopes_list = get_envelopes_list,
-  .sess_remove_message = NULL,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = NULL,
-  .sess_get_message_by_uid = get_message_by_uid,
-  .sess_login_sasl = NULL,
-
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * maildir_session_driver = &local_maildir_session_driver;
