@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mhdriver_cached.c,v 1.46 2006/06/26 11:50:26 hoa Exp $
+ * $Id: mhdriver_cached.c,v 1.50 2008/02/20 22:15:50 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -41,7 +41,7 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #else
 #	include <dirent.h>
@@ -143,7 +143,6 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_mh_cached_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "mh-cached",
 
   /* sess_initialize */ mhdriver_cached_initialize,
@@ -189,56 +188,7 @@ static mailsession_driver local_mh_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "mh-cached",
-
-  .sess_initialize = mhdriver_cached_initialize,
-  .sess_uninitialize = mhdriver_cached_uninitialize,
-
-  .sess_parameters = mhdriver_cached_parameters,
-
-  .sess_connect_stream = NULL,
-  .sess_connect_path = mhdriver_cached_connect_path,
-  .sess_starttls = NULL,
-  .sess_login = NULL,
-  .sess_logout = mhdriver_cached_logout,
-  .sess_noop = NULL,
-
-  .sess_build_folder_name = mhdriver_cached_build_folder_name,
-  .sess_create_folder = mhdriver_cached_create_folder,
-  .sess_delete_folder = mhdriver_cached_delete_folder,
-  .sess_rename_folder = mhdriver_cached_rename_folder,
-  .sess_check_folder = mhdriver_cached_check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = mhdriver_cached_select_folder,
-  .sess_expunge_folder = mhdriver_cached_expunge_folder,
-  .sess_status_folder = mhdriver_cached_status_folder,
-  .sess_messages_number = mhdriver_cached_messages_number,
-  .sess_recent_number = mhdriver_cached_recent_number,
-  .sess_unseen_number = mhdriver_cached_unseen_number,
-  .sess_list_folders = mhdriver_cached_list_folders,
-  .sess_lsub_folders = mhdriver_cached_lsub_folders,
-  .sess_subscribe_folder = mhdriver_cached_subscribe_folder,
-  .sess_unsubscribe_folder = mhdriver_cached_unsubscribe_folder,
-
-  .sess_append_message = mhdriver_cached_append_message,
-  .sess_append_message_flags = mhdriver_cached_append_message_flags,
-  .sess_copy_message = mhdriver_cached_copy_message,
-  .sess_move_message = mhdriver_cached_move_message,
-
-  .sess_get_messages_list = mhdriver_cached_get_messages_list,
-  .sess_get_envelopes_list = mhdriver_cached_get_envelopes_list,
-  .sess_remove_message = mhdriver_cached_remove_message,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = mhdriver_cached_get_message,
-  .sess_get_message_by_uid = mhdriver_cached_get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 mailsession_driver * mh_cached_session_driver =
@@ -1082,11 +1032,6 @@ get_cached_envelope(struct mail_cache_db * cache_db, MMAPString * mmapstr,
   
   folder = get_mh_cur_folder(session);
 
-#if 0
-  msg_info = cinthash_find(mh_data->mh_cur_folder->fl_msgs_hash, num);
-  if (msg_info == NULL)
-    return MAIL_ERROR_CACHE_MISS;
-#endif
   key.data = &num;
   key.len = sizeof(num);
   r = chash_get(folder->fl_msgs_hash, &key, &data);
@@ -1126,13 +1071,6 @@ write_cached_envelope(struct mail_cache_db * cache_db, MMAPString * mmapstr,
   struct mailmh_msg_info * msg_info;
 
   folder = get_mh_cur_folder(session);
-#if 0
-  msg_info = cinthash_find(mh_data->mh_cur_folder->fl_msgs_hash, num);
-  if (msg_info == NULL) {
-    res = MAIL_ERROR_CACHE_MISS;
-    goto err;
-  }
-#endif
   key.data = &num;
   key.len = sizeof(num);
   r = chash_get(folder->fl_msgs_hash, &key, &data);
@@ -1192,7 +1130,7 @@ mhdriver_cached_get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
@@ -1201,7 +1139,7 @@ mhdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto close_db_env;
   }
 
@@ -1244,13 +1182,13 @@ mhdriver_cached_get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto close_db_env;
   }
   
@@ -1327,7 +1265,7 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     const char * uid,
     mailmessage ** result)
 {
-  uint32_t index;
+  uint32_t indx;
   char *p;
   struct mailmh_msg_info * mh_msg_info;
   struct mailmh_folder * folder;
@@ -1340,15 +1278,15 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
   if (uid == NULL)
     return MAIL_ERROR_INVAL;
 
-  index = strtoul(uid, &p, 10);
+  indx = strtoul(uid, &p, 10);
   if (p == uid || * p != '-')
     return MAIL_ERROR_INVAL;
   
   folder = get_mh_cur_folder(session);
   
   mh_msg_info = NULL;
-  key.data = &index;
-  key.len = sizeof(index);
+  key.data = &indx;
+  key.len = sizeof(indx);
   r = chash_get(folder->fl_msgs_hash, &key, &data);
   if (r < 0)
     return MAIL_ERROR_MSG_NOT_FOUND;
@@ -1365,7 +1303,7 @@ static int mhdriver_cached_get_message_by_uid(mailsession * session,
     size_p = p + 1;
     size = strtoul(size_p, &p, 10);
     if ((* p == '\0') && (size == mh_msg_info->msg_size))
-      return mhdriver_cached_get_message(session, index, result);
+      return mhdriver_cached_get_message(session, indx, result);
   }
   else if (*p != '-') {
     return MAIL_ERROR_INVAL;
