@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver.c,v 1.51 2006/06/26 11:50:27 hoa Exp $
+ * $Id: nntpdriver.c,v 1.52 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,7 +104,6 @@ static int nntpdriver_get_message_by_uid(mailsession * session,
 static int nntpdriver_noop(mailsession * session);
 
 static mailsession_driver local_nntp_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "nntp",
 
   /* sess_initialize */ nntpdriver_initialize,
@@ -150,56 +149,7 @@ static mailsession_driver local_nntp_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "nntp",
-
-  .sess_initialize = nntpdriver_initialize,
-  .sess_uninitialize = nntpdriver_uninitialize,
-
-  .sess_parameters = nntpdriver_parameters,
-
-  .sess_connect_stream = nntpdriver_connect_stream,
-  .sess_connect_path = NULL,
-  .sess_starttls = NULL,
-  .sess_login = nntpdriver_login,
-  .sess_logout = nntpdriver_logout,
-  .sess_noop = nntpdriver_noop,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = NULL,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = nntpdriver_select_folder,
-  .sess_expunge_folder = NULL,
-  .sess_status_folder = nntpdriver_status_folder,
-  .sess_messages_number = nntpdriver_messages_number,
-  .sess_recent_number = nntpdriver_messages_number,
-  .sess_unseen_number = nntpdriver_messages_number,
-  .sess_list_folders = nntpdriver_list_folders,
-  .sess_lsub_folders = nntpdriver_lsub_folders,
-  .sess_subscribe_folder = nntpdriver_subscribe_folder,
-  .sess_unsubscribe_folder = nntpdriver_unsubscribe_folder,
-
-  .sess_append_message = nntpdriver_append_message,
-  .sess_append_message_flags = nntpdriver_append_message_flags,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = nntpdriver_get_messages_list,
-  .sess_get_envelopes_list = nntpdriver_get_envelopes_list,
-  .sess_remove_message = NULL,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = nntpdriver_get_message,
-  .sess_get_message_by_uid = nntpdriver_get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 
