@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: nntpdriver_cached.c,v 1.53 2006/06/26 11:50:27 hoa Exp $
+ * $Id: nntpdriver_cached.c,v 1.56 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,7 +50,7 @@
 #	include <unistd.h>
 #endif
 #include <stdlib.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
@@ -139,7 +139,6 @@ static int nntpdriver_cached_get_message_by_uid(mailsession * session,
     mailmessage ** result);
 
 static mailsession_driver local_nntp_cached_session_driver = {
-#if ! defined __STDC_VERSION__ || __STDC_VERSION__ < 199901L
   /* sess_name */ "nntp-cached",
 
   /* sess_initialize */ nntpdriver_cached_initialize,
@@ -185,56 +184,7 @@ static mailsession_driver local_nntp_cached_session_driver = {
 #if 0
   /* sess_search_messages */ maildriver_generic_search_messages,
 #endif
-  /* sess_login_sasl */ NULL,
-
-#else
-  .sess_name = "nntp-cached",
-
-  .sess_initialize = nntpdriver_cached_initialize,
-  .sess_uninitialize = nntpdriver_cached_uninitialize,
-
-  .sess_parameters = nntpdriver_cached_parameters,
-
-  .sess_connect_stream = nntpdriver_cached_connect_stream,
-  .sess_connect_path = NULL,
-  .sess_starttls = NULL,
-  .sess_login = nntpdriver_cached_login,
-  .sess_logout = nntpdriver_cached_logout,
-  .sess_noop = nntpdriver_cached_noop,
-
-  .sess_build_folder_name = NULL,
-  .sess_create_folder = NULL,
-  .sess_delete_folder = NULL,
-  .sess_rename_folder = NULL,
-  .sess_check_folder = nntpdriver_cached_check_folder,
-  .sess_examine_folder = NULL,
-  .sess_select_folder = nntpdriver_cached_select_folder,
-  .sess_expunge_folder = NULL,
-  .sess_status_folder = nntpdriver_cached_status_folder,
-  .sess_messages_number = nntpdriver_cached_messages_number,
-  .sess_recent_number = nntpdriver_cached_recent_number,
-  .sess_unseen_number = nntpdriver_cached_unseen_number,
-  .sess_list_folders = nntpdriver_cached_list_folders,
-  .sess_lsub_folders = nntpdriver_cached_lsub_folders,
-  .sess_subscribe_folder = nntpdriver_cached_subscribe_folder,
-  .sess_unsubscribe_folder = nntpdriver_cached_unsubscribe_folder,
-
-  .sess_append_message = nntpdriver_cached_append_message,
-  .sess_append_message_flags = nntpdriver_cached_append_message_flags,
-  .sess_copy_message = NULL,
-  .sess_move_message = NULL,
-
-  .sess_get_messages_list = nntpdriver_cached_get_messages_list,
-  .sess_get_envelopes_list = nntpdriver_cached_get_envelopes_list,
-  .sess_remove_message = NULL,
-#if 0
-  .sess_search_messages = maildriver_generic_search_messages,
-#endif
-
-  .sess_get_message = nntpdriver_cached_get_message,
-  .sess_get_message_by_uid = nntpdriver_cached_get_message_by_uid,
-  .sess_login_sasl = NULL,
-#endif
+  /* sess_login_sasl */ NULL
 };
 
 
@@ -548,7 +498,7 @@ static int nntpdriver_cached_status_folder(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto err;
   }
 
@@ -922,7 +872,7 @@ nntpdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
 
@@ -962,7 +912,7 @@ nntpdriver_cached_get_envelopes_list(mailsession * session,
 
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
@@ -995,13 +945,13 @@ nntpdriver_cached_get_envelopes_list(mailsession * session,
   
   r = mail_cache_db_open_lock(filename_env, &cache_db_env);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto free_mmapstr;
   }
   
   r = mail_cache_db_open_lock(filename_flags, &cache_db_flags);
   if (r < 0) {
-    res = MAIL_ERROR_MEMORY;
+    res = MAIL_ERROR_FILE;
     goto close_db_env;
   }
 
