@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver.c,v 1.40 2006/12/26 13:13:23 hoa Exp $
+ * $Id: pop3driver.c,v 1.42 2007/06/30 12:58:21 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -80,6 +80,9 @@ static int pop3driver_get_messages_list(mailsession * session,
 static int pop3driver_get_message(mailsession * session,
 				  uint32_t num, mailmessage ** result);
 
+static int pop3driver_get_message_by_uid(mailsession * session,
+    const char * uid, mailmessage ** result);
+
 static int pop3driver_login_sasl(mailsession * session,
     const char * auth_type,
     const char * server_fqdn,
@@ -126,7 +129,7 @@ static mailsession_driver local_pop3_session_driver = {
   /* sess_move_message */ NULL,
 
   /* sess_get_message */ pop3driver_get_message,
-  /* sess_get_message_by_uid */ NULL,
+  /* sess_get_message_by_uid */ pop3driver_get_message_by_uid,
 
   /* sess_get_messages_list */ pop3driver_get_messages_list,
   /* sess_get_envelopes_list */ maildriver_generic_get_envelopes_list,
@@ -213,30 +216,6 @@ static int pop3driver_starttls(mailsession * session)
   data = get_data(session);
   pop3 = get_pop3_session(session);
 
-#if 0
-  r = mailpop3_stls(pop3);
-
-  switch (r) {
-  case MAILPOP3_NO_ERROR:
-    break;
-  default:
-    return pop3driver_pop3_error_to_mail_error(r);
-  }
-
-  low = mailstream_get_low(pop3->pop3_stream);
-  fd = mailstream_low_get_fd(low);
-  if (fd == -1)
-    return MAIL_ERROR_STREAM;
-  
-  new_low = mailstream_low_tls_open_with_callback(fd,
-      data->pop3_ssl_callback, data->pop3_ssl_cb_data);
-  if (new_low == NULL)
-    return MAIL_ERROR_SSL;
-  mailstream_low_free(low);
-  mailstream_set_low(pop3->pop3_stream, new_low);
-  
-  return MAIL_NO_ERROR;
-#endif
   r = mailpop3_socket_starttls(pop3);
   return pop3driver_pop3_error_to_mail_error(r);
 }
@@ -412,6 +391,44 @@ static int pop3driver_get_message(mailsession * session,
   return MAIL_NO_ERROR;
 }
 
+static int pop3driver_get_message_by_uid(mailsession * session,
+    const char * uid, mailmessage ** result)
+{
+  mailpop3 * pop3;
+  struct mailpop3_msg_info * msg_info;
+  int found;
+  unsigned int i;
+  
+  if (uid == NULL)
+    return MAIL_ERROR_INVAL;
+  
+  pop3 = get_pop3_session(session);
+  
+  found = 0;
+  
+  /* iterate all messages and look for uid */
+  for(i = 0 ; i < carray_count(pop3->pop3_msg_tab) ; i++) {
+    msg_info = carray_get(pop3->pop3_msg_tab, i);
+    
+    if (msg_info == NULL)
+      continue;
+    
+    if (msg_info->msg_deleted)
+      continue;
+    
+    /* uid found, stop looking */
+    if (strcmp(msg_info->msg_uidl, uid) == 0) {
+      found = 1;
+      break;
+    }
+  }
+  
+  if (!found)
+    return MAIL_ERROR_MSG_NOT_FOUND;
+  
+  return pop3driver_get_message(session, msg_info->msg_index, result);
+}
+
 static int pop3driver_login_sasl(mailsession * session,
     const char * auth_type,
     const char * server_fqdn,
