@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: pop3driver_tools.c,v 1.15 2006/12/13 18:31:31 hoa Exp $
+ * $Id: pop3driver_tools.c,v 1.17 2008/02/20 22:15:51 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -104,7 +104,7 @@ int pop3driver_pop3_error_to_mail_error(int error)
   default:
     return MAIL_ERROR_INVAL;
   }
-};
+}
 
 static inline struct pop3_session_state_data *
 session_get_data(mailsession * session)
@@ -142,14 +142,14 @@ cached_session_get_pop3_session(mailsession * session)
 }
 
 
-int pop3driver_retr(mailsession * session, uint32_t index,
+int pop3driver_retr(mailsession * session, uint32_t indx,
 		    char ** result, size_t * result_len)
 {
   char * msg_content;
   size_t msg_length;
   int r;
 
-  r = mailpop3_retr(session_get_pop3_session(session), index,
+  r = mailpop3_retr(session_get_pop3_session(session), indx,
       &msg_content, &msg_length);
   
   switch (r) {
@@ -165,7 +165,7 @@ int pop3driver_retr(mailsession * session, uint32_t index,
   return MAIL_NO_ERROR;
 }
 
-int pop3driver_header(mailsession * session, uint32_t index,
+int pop3driver_header(mailsession * session, uint32_t indx,
 		      char ** result,
 		      size_t * result_len)
 {
@@ -174,7 +174,7 @@ int pop3driver_header(mailsession * session, uint32_t index,
   int r;
   
   r = mailpop3_header(session_get_pop3_session(session),
-      index, &headers, &headers_length);
+      indx, &headers, &headers_length);
   
   switch (r) {
   case MAILPOP3_NO_ERROR:
@@ -189,7 +189,7 @@ int pop3driver_header(mailsession * session, uint32_t index,
   return MAIL_NO_ERROR;
 }
 
-int pop3driver_size(mailsession * session, uint32_t index,
+int pop3driver_size(mailsession * session, uint32_t indx,
 		    size_t * result)
 {
   mailpop3 * pop3;
@@ -201,7 +201,7 @@ int pop3driver_size(mailsession * session, uint32_t index,
 
   mailpop3_list(pop3, &msg_tab);
 
-  r = mailpop3_get_msg_info(pop3, index, &info);
+  r = mailpop3_get_msg_info(pop3, indx, &info);
   switch (r) {
   case MAILPOP3_NO_ERROR:
     break;
