@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailprivacy_tools.c,v 1.10 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailprivacy_tools.c,v 1.13 2008/02/17 13:13:27 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,12 +38,18 @@
 #endif
 
 #include "mailprivacy_tools.h"
+#include "mailprivacy_tools_private.h"
 
 #include <stdlib.h>
 #include <string.h>
-#include <libgen.h>
 #include <unistd.h>
-#include <sys/mman.h>
+#ifdef WIN32
+#	include "win_etpan.h"
+#else
+#	include <libgen.h>
+#	include <sys/mman.h>
+#	include <sys/wait.h>
+#endif
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -1309,3 +1315,274 @@ int mailprivacy_fetch_decoded_to_file(struct mailprivacy * privacy,
   return res;
 }
 
+
+
+#ifdef HAVE_MINGW32_SYSTEM
+/* Define to 1 do enable debugging.  */
+#define DEBUG_W32_SPAWN 0
+
+/* Create pipe where the read end is inheritable.  */
+static int
+create_inheritable_pipe (HANDLE filedes[2])
+{
+  HANDLE r, w, h;
+  SECURITY_ATTRIBUTES sec_attr;
+
+  memset (&sec_attr, 0, sizeof sec_attr);
+  sec_attr.nLength = sizeof sec_attr;
+  sec_attr.bInheritHandle = FALSE;
+    
+  if (!CreatePipe (&r, &w, &sec_attr, 0))
+    return -1;
+
+  if (!DuplicateHandle (GetCurrentProcess(), r,
+                        GetCurrentProcess(), &h, 0,
+                        TRUE, DUPLICATE_SAME_ACCESS ))
+    {
+      CloseHandle (r);
+      CloseHandle (w);
+      return -1;
+    }
+  CloseHandle (w);
+  w = h;
+
+  filedes[0] = r;
+  filedes[1] = w;
+  return 0;
+}
+#endif /*HAVE_MINGW32_SYSTEM*/
+
+
+int mailprivacy_spawn_and_wait(char * command, char * passphrase,
+    char * stdoutfile, char * stderrfile,
+    int * bad_passphrase)
+{
+#ifdef WIN32
+  int res;
+  SECURITY_ATTRIBUTES sec_attr;
+  PROCESS_INFORMATION pi = 
+    {
+      NULL,      /* Returns process handle.  */
+      0,         /* Returns primary thread handle.  */
+      0,         /* Returns pid.  */
+      0          /* Returns tid.  */
+    };
+  STARTUPINFO si;
+  int cr_flags;
+  HANDLE wp_passphrase[2];
+  HANDLE fd_out;
+  HANDLE fd_err;
+  int code;
+
+  /* Prepare security attributes.  */
+  memset (&sec_attr, 0, sizeof sec_attr);
+  sec_attr.nLength = sizeof sec_attr;
+  sec_attr.bInheritHandle = TRUE;
+
+  fd_out = CreateFile (stdoutfile,
+		       GENERIC_READ|GENERIC_WRITE,
+		       FILE_SHARE_READ|FILE_SHARE_WRITE,
+		       &sec_attr,
+		       CREATE_ALWAYS,
+		       FILE_ATTRIBUTE_NORMAL,
+		       NULL);
+  if (fd_out == INVALID_HANDLE_VALUE)
+    {
+      res = ERROR_PASSPHRASE_FILE;
+      goto err;
+    }
+
+  fd_err = CreateFile (stderrfile,
+		       GENERIC_READ|GENERIC_WRITE,
+		       FILE_SHARE_READ|FILE_SHARE_WRITE,
+		       &sec_attr,
+		       CREATE_ALWAYS,
+		       FILE_ATTRIBUTE_NORMAL,
+		       NULL);
+  if (fd_err == INVALID_HANDLE_VALUE)
+    {
+      res = ERROR_PASSPHRASE_FILE;
+      goto close_out;
+    }
+
+  /* Create a pipe for the passphrase.  */
+  if (create_inheritable_pipe (wp_passphrase))
+    {
+      res = ERROR_PASSPHRASE_FILE;
+      goto close_err;
+    }
+
+  /* Prepare security attributes.  */
+  memset (&sec_attr, 0, sizeof sec_attr);
+  sec_attr.nLength = sizeof sec_attr;
+  sec_attr.bInheritHandle = FALSE;
+  
+  /* Start the process.  */
+  memset (&si, 0, sizeof si);
+  si.cb = sizeof (si);
+  si.dwFlags = STARTF_USESTDHANDLES | STARTF_USESHOWWINDOW;
+  si.wShowWindow = DEBUG_W32_SPAWN ? SW_SHOW : SW_MINIMIZE;
+  si.hStdInput  = wp_passphrase[0];
+  si.hStdOutput = fd_out;
+  si.hStdError  = fd_err;
+
+  cr_flags = (CREATE_DEFAULT_ERROR_MODE
+              | GetPriorityClass (GetCurrentProcess ())
+              | CREATE_SUSPENDED); 
+  if (!CreateProcess (NULL,          /* Program to start.  */
+                      command,       /* Command line arguments.  */
+                      &sec_attr,     /* Process security attributes.  */
+                      &sec_attr,     /* Thread security attributes.  */
+                      TRUE,          /* Inherit handles.  */
+                      cr_flags,      /* Creation flags.  */
+                      NULL,          /* Environment.  */
+                      NULL,          /* Use current drive/directory.  */
+                      &si,           /* Startup information. */
+                      &pi            /* Returns process information.  */
+                      ))
+    {
+      CloseHandle (wp_passphrase[0]);
+      CloseHandle (wp_passphrase[1]);
+
+      res = ERROR_PASSPHRASE_COMMAND;
+      goto close_err;
+    }
+
+  /* Close the other end of the pipe.  */
+  CloseHandle (wp_passphrase[0]);
+  CloseHandle (fd_out);
+  CloseHandle (fd_err);
+  /* Process has been created suspended; resume it now. */
+  ResumeThread (pi.hThread);
+  CloseHandle (pi.hThread); 
+
+  if ((passphrase != NULL) && (strlen(passphrase) > 0)) {
+    DWORD written;
+    WriteFile (wp_passphrase[1], passphrase, strlen(passphrase),
+	       &written, NULL);
+  }
+  else {
+    DWORD written;
+    /* dummy password */
+    WriteFile(wp_passphrase[1], "*dummy*", 7, &written, NULL);
+  }
+  CloseHandle(wp_passphrase[1]);
+
+  code = WaitForSingleObject (pi.hProcess, INFINITE);
+  if (code == WAIT_OBJECT_0)
+    {
+      DWORD exc;
+      if (GetExitCodeProcess (pi.hProcess, &exc))
+	{
+	  if (exc)
+	    *bad_passphrase = 1;
+	}
+      else
+	res = ERROR_PASSPHRASE_COMMAND;
+    }
+  else
+    res = ERROR_PASSPHRASE_COMMAND;
+
+  CloseHandle (pi.hProcess);
+  return 0;
+
+ close_err:
+  CloseHandle (fd_err);
+ close_out:
+  CloseHandle (fd_out);
+ err:
+  return res;
+#else
+  int res;
+  int fd_out;
+  int fd_err;
+  pid_t pid;
+  int passphrase_input[2];
+  int r;
+
+  fd_out = open(stdoutfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
+  if (fd_out < 0) {
+    res = ERROR_PASSPHRASE_FILE;
+    goto err;
+  }
+  
+  fd_err = open(stderrfile, O_RDWR | O_CREAT | O_TRUNC, 0600);
+  if (fd_err < 0) {
+    res = ERROR_PASSPHRASE_FILE;
+    goto close_out;
+  }
+  
+  r = pipe(passphrase_input);
+  if (r < 0) {
+    res = ERROR_PASSPHRASE_FILE;
+    goto close_err;
+  }
+  
+  pid = fork();
+  switch (pid) {
+  case -1:
+    {
+      close (passphrase_input[0]);
+      close (passphrase_input[1]);
+      res = ERROR_PASSPHRASE_COMMAND;
+      goto close_err;
+    }
+    
+  case 0:
+    /* child */
+    {
+      int status;
+      
+      /* close unneeded fd */
+      close(passphrase_input[1]);
+      
+      dup2(passphrase_input[0], 0);
+      close(passphrase_input[0]);
+      dup2(fd_out, 1);
+      close(fd_out);
+      dup2(fd_err, 2);
+      close(fd_err);
+      
+      status = system(command);
+      
+      exit(WEXITSTATUS(status));
+    }
+    break;
+    
+  default:
+    /* parent */
+    {
+      int status;
+      
+      /* close unneeded fd */
+      close(fd_err);
+      close(fd_out);
+      close(passphrase_input[0]);
+      
+      if ((passphrase != NULL) && (strlen(passphrase) > 0)) {
+        write(passphrase_input[1], passphrase, strlen(passphrase));
+      }
+      else {
+        /* dummy password */
+        write(passphrase_input[1], "*dummy*", 7);
+      }
+      close(passphrase_input[1]);
+      
+      waitpid(pid, &status, 0);
+      
+      if (WEXITSTATUS(status) != 0)
+        *bad_passphrase = 1;
+    }
+    break;
+  }
+  
+ close_err:
+  close(fd_err);
+ close_out:
+  close(fd_out);
+ err:
+  return res;
+#endif
+}
+
+
