@@ -349,7 +349,7 @@ void mailimap_annotatemore_entry_att_list_free(
 
 LIBETPAN_EXPORT
 struct mailimap_annotatemore_entry_att_list *
-mailimap_annotatemore_entry_att_list_new_empty()
+mailimap_annotatemore_entry_att_list_new_empty(void)
 {
   clist * list;
 
