@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap.c,v 1.41 2007/05/25 01:31:18 hoa Exp $
+ * $Id: mailimap.c,v 1.43 2008/02/20 22:35:48 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -587,7 +587,7 @@ int mailimap_append(mailimap * session, const char * mailbox,
   int r;
   int error_code;
   struct mailimap_continue_req * cont_req;
-  size_t index;
+  size_t indx;
   size_t fixed_literal_size;
   
   if ((session->imap_state != MAILIMAP_STATE_AUTHENTICATED) &&
@@ -611,11 +611,11 @@ int mailimap_append(mailimap * session, const char * mailbox,
   if (mailimap_read_line(session) == NULL)
     return MAILIMAP_ERROR_STREAM;
 
-  index = 0;
+  indx = 0;
 
   r = mailimap_continue_req_parse(session->imap_stream,
       session->imap_stream_buffer,
-      &index, &cont_req,
+      &indx, &cont_req,
       session->imap_progr_rate, session->imap_progr_fun);
   if (r == MAILIMAP_NO_ERROR)
     mailimap_continue_req_free(cont_req);
@@ -1564,7 +1564,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
   struct mailimap_response * response;
   int r;
   int error_code;
-  size_t index;
+  size_t indx;
   struct mailimap_cont_req_or_resp_data * cont_or_resp_data;
   sasl_callback_t sasl_callback[5];
   const char * sasl_out;
@@ -1660,7 +1660,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
   
   while (1) {
     struct mailimap_continue_req * cont_req;
-    char * response;
+    char * response_base64;
     int got_response;
     char * encoded;
     unsigned int encoded_len;
@@ -1671,23 +1671,23 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       goto free_sasl_conn;
     }
     
-    index = 0;
+    indx = 0;
     
     r = mailimap_continue_req_parse(session->imap_stream,
         session->imap_stream_buffer,
-        &index, &cont_req,
+        &indx, &cont_req,
         session->imap_progr_rate, session->imap_progr_fun);
     if (r != MAILIMAP_NO_ERROR)
       break;
     
     got_response = 1;
     if (cont_req->cr_type == MAILIMAP_CONTINUE_REQ_BASE64) {
-      response = cont_req->cr_data.cr_base64;
-      if (* response == '\0')
+      response_base64 = cont_req->cr_data.cr_base64;
+      if (* response_base64 == '\0')
         got_response = 0;
     }
     else {
-      response = "";
+      response_base64 = "";
       got_response = 0;
     }
     
@@ -1697,7 +1697,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
       unsigned int decoded_len;
       unsigned int max_decoded;
       
-      response_len = strlen(response);
+      response_len = strlen(response_base64);
       max_decoded = response_len * 3 / 4;
       decoded = malloc(max_decoded + 1);
       if (decoded == NULL) {
@@ -1706,7 +1706,7 @@ int mailimap_authenticate(mailimap * session, const char * auth_type,
         goto free_sasl_conn;
       }
       
-      r = sasl_decode64(response, response_len,
+      r = sasl_decode64(response_base64, response_len,
           decoded, max_decoded + 1, &decoded_len);
       
       mailimap_continue_req_free(cont_req);
@@ -2385,18 +2385,18 @@ int mailimap_send_current_tag(mailimap * session)
 int mailimap_parse_response(mailimap * session,
     struct mailimap_response ** result)
 {
-  size_t index;
+  size_t indx;
   struct mailimap_response * response;
   char tag_str[15];
   int r;
   
-  index = 0;
+  indx = 0;
 
   session->imap_response = NULL;
 
   r = mailimap_response_parse(session->imap_stream,
       session->imap_stream_buffer,
-      &index, &response,
+      &indx, &response,
       session->imap_progr_rate, session->imap_progr_fun);
   if (r != MAILIMAP_NO_ERROR)
     return r;
@@ -2436,17 +2436,17 @@ int mailimap_parse_response(mailimap * session,
 static int parse_greeting(mailimap * session,
 	 			struct mailimap_greeting ** result)
 {
-  size_t index;
+  size_t indx;
   struct mailimap_greeting * greeting;
   int r;
   
-  index = 0;
+  indx = 0;
   
   session->imap_response = NULL;
 
   r = mailimap_greeting_parse(session->imap_stream,
       session->imap_stream_buffer,
-      &index, &greeting, session->imap_progr_rate,
+      &indx, &greeting, session->imap_progr_rate,
       session->imap_progr_fun);
   if (r != MAILIMAP_NO_ERROR)
     return r;
