@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_socket.c,v 1.16 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailimap_socket.c,v 1.17 2006/12/26 13:13:24 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -81,3 +81,41 @@ int mailimap_socket_connect(mailimap * f, const char * server, uint16_t port)
   
   return mailimap_connect(f, stream);
 }
+
+
+int mailimap_socket_starttls(mailimap * f)
+{
+  return mailimap_socket_starttls_with_callback(f, NULL, NULL);
+}
+
+int mailimap_socket_starttls_with_callback(mailimap * f,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
+{
+  mailstream_low * low;
+  mailstream_low * new_low;
+  int r;
+  int fd;
+  
+  r = mailimap_starttls(f);
+  
+  switch (r) {
+  case MAILIMAP_NO_ERROR:
+    break;
+  default:
+    return r;
+  }
+
+  low = mailstream_get_low(f->imap_stream);
+  fd = mailstream_low_get_fd(low);
+  if (fd == -1)
+    return MAILIMAP_ERROR_STREAM;
+  
+  new_low = mailstream_low_tls_open_with_callback(fd, callback, data);
+  if (new_low == NULL)
+    return MAILIMAP_ERROR_STREAM;
+  
+  mailstream_low_free(low);
+  mailstream_set_low(f->imap_stream, new_low);
+  
+  return MAILIMAP_NO_ERROR;
+}
