@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_ssl.c,v 1.14 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailimap_ssl.c,v 1.16 2006/12/26 13:13:24 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,7 +55,8 @@
 #define SERVICE_NAME_IMAPS "imaps"
 #define SERVICE_TYPE_TCP "tcp"
 
-int mailimap_ssl_connect(mailimap * f, const char * server, uint16_t port)
+int mailimap_ssl_connect_with_callback(mailimap * f, const char * server, uint16_t port,
+    void (* callback)(struct mailstream_ssl_context * ssl_context, void * data), void * data)
 {
   int s;
   mailstream * stream;
@@ -72,11 +73,17 @@ int mailimap_ssl_connect(mailimap * f, const char * server, uint16_t port)
   if (s == -1)
     return MAILIMAP_ERROR_CONNECTION_REFUSED;
 
-  stream = mailstream_ssl_open(s);
+  stream = mailstream_ssl_open_with_callback(s, callback, data);
   if (stream == NULL) {
     close(s);
-    return MAILIMAP_ERROR_CONNECTION_REFUSED;
+    return MAILIMAP_ERROR_SSL;
   }
 
   return mailimap_connect(f, stream);
 }
+
+int mailimap_ssl_connect(mailimap * f, const char * server, uint16_t port)
+{
+  return mailimap_ssl_connect_with_callback(f, server, port,
+      NULL, NULL);
+}
