@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailimap_types.c,v 1.24 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailimap_types.c,v 1.26 2006/10/25 23:10:59 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,6 +43,7 @@
 #include "mailimap_extension.h"
 
 #include <stdlib.h>
+#include <stdio.h>
 
 /* ************************************************************************* */
 /* ************************************************************************* */
@@ -2918,7 +2919,7 @@ mailimap_response_info_new(void)
   resp_info->rsp_trycreate = FALSE;
   resp_info->rsp_mailbox_list = clist_new();
   resp_info->rsp_extension_list = clist_new();
-  if (resp_info->rsp_mailbox_list == NULL)
+  if (resp_info->rsp_extension_list == NULL)
     goto free;
   resp_info->rsp_mailbox_lsub = clist_new();
   if (resp_info->rsp_mailbox_lsub == NULL)
@@ -2933,7 +2934,9 @@ mailimap_response_info_new(void)
   resp_info->rsp_fetch_list = clist_new();
   if (resp_info->rsp_fetch_list == NULL)
     goto free_expunged;
-
+  resp_info->rsp_atom = NULL;
+  resp_info->rsp_value = NULL;
+  
   return resp_info;
 
  free_expunged:
@@ -2953,6 +2956,8 @@ mailimap_response_info_new(void)
 void
 mailimap_response_info_free(struct mailimap_response_info * resp_info)
 {
+  free(resp_info->rsp_value);
+  free(resp_info->rsp_atom);
   if (resp_info->rsp_alert != NULL)
     free(resp_info->rsp_alert);
   if (resp_info->rsp_parse != NULL)
