@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailmime_types_helper.c,v 1.26 2006/06/26 11:50:27 hoa Exp $
+ * $Id: mailmime_types_helper.c,v 1.28 2008/01/14 17:13:53 hoa Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +49,7 @@
 #	include <unistd.h>
 #endif
 #include <stdlib.h>
-#ifdef _MSC_VER
+#ifdef WIN32
 #	include "win_etpan.h"
 #endif
 
@@ -507,7 +507,7 @@ mailmime_new_message_data(struct mailmime * msg_mime)
 
 #define MAX_MESSAGE_ID 512
 
-static char * generate_boundary()
+char * mailmime_generate_boundary(void)
 {
   char id[MAX_MESSAGE_ID];
   time_t now;
@@ -576,7 +576,7 @@ mailmime_new_empty(struct mailmime_content * content,
     if (attr_name == NULL)
       goto free_list;
 
-    boundary = generate_boundary();
+    boundary = mailmime_generate_boundary();
     attr_value = boundary;
     if (attr_name == NULL) {
       free(attr_name);
