@@ -30,19 +30,23 @@
  */
 
 /*
- * $Id: newsnntp_socket.c,v 1.11 2005/06/01 12:22:20 smarinier Exp $
+ * $Id: newsnntp_socket.c,v 1.14 2006/06/26 11:50:28 hoa Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#	include <config.h>
+#endif
+
 #include "newsnntp_socket.h"
 
 #include "newsnntp.h"
 
 #include "connect.h"
 
-#if HAVE_NETINET_IN_H
+#ifdef HAVE_NETINET_IN_H
 #	include <netinet/in.h>
 #endif
-#if HAVE_UNISTD_H
+#ifdef HAVE_UNISTD_H
 #	include <unistd.h>
 #endif
 
@@ -59,7 +63,6 @@ int newsnntp_socket_connect(newsnntp * f, const char * server, uint16_t port)
     port = mail_get_service_port(SERVICE_NAME_NNTP, SERVICE_TYPE_TCP);
     if (port == 0)
       port = DEFAULT_NNTP_PORT;
-    port = ntohs(port);
   }
 
   /* Connection */
