@@ -30,7 +30,7 @@
  */
 
 /*
- * $Id: mailpop3.c,v 1.30 2007/07/21 18:44:40 hoa Exp $
+ * $Id: mailpop3.c,v 1.32 2008/02/20 22:15:53 hoa Exp $
  */
 
 /*
@@ -76,14 +76,14 @@ enum {
 */
 
 static struct mailpop3_msg_info *
-mailpop3_msg_info_new(unsigned int index, uint32_t size, char * uidl)
+mailpop3_msg_info_new(unsigned int indx, uint32_t size, char * uidl)
 {
   struct mailpop3_msg_info * msg;
 
   msg = malloc(sizeof(* msg));
   if (msg == NULL)
     return NULL;
-  msg->msg_index = index;
+  msg->msg_index = indx;
   msg->msg_size = size;
   msg->msg_deleted = FALSE;
   msg->msg_uidl = uidl;
@@ -123,24 +123,24 @@ static void mailpop3_msg_info_tab_reset(carray * msg_tab)
 }
 
 static inline struct mailpop3_msg_info *
-mailpop3_msg_info_tab_find_msg(carray * msg_tab, unsigned int index)
+mailpop3_msg_info_tab_find_msg(carray * msg_tab, unsigned int indx)
 {
   struct mailpop3_msg_info * msg;
 
-  if (index == 0)
+  if (indx == 0)
     return NULL;
 
-  if (index > carray_count(msg_tab))
+  if (indx > carray_count(msg_tab))
     return NULL;
 
-  msg = carray_get(msg_tab, index - 1);
+  msg = carray_get(msg_tab, indx - 1);
 
   return msg;
 }
 
 
 
-int mailpop3_get_msg_info(mailpop3 * f, unsigned int index,
+int mailpop3_get_msg_info(mailpop3 * f, unsigned int indx,
 			   struct mailpop3_msg_info ** result)
 {
   carray * tab;
@@ -151,7 +151,7 @@ int mailpop3_get_msg_info(mailpop3 * f, unsigned int index,
   if (tab == NULL)
     return MAILPOP3_ERROR_BAD_STATE;
 
-  info = mailpop3_msg_info_tab_find_msg(tab, index);
+  info = mailpop3_msg_info_tab_find_msg(tab, indx);
   if (info == NULL)
     return MAILPOP3_ERROR_NO_SUCH_MESSAGE;
 
@@ -642,14 +642,14 @@ void mailpop3_list(mailpop3 * f, carray ** result)
 }
 
 static inline struct mailpop3_msg_info *
-find_msg(mailpop3 * f, unsigned int index)
+find_msg(mailpop3 * f, unsigned int indx)
 {
   mailpop3_list_if_needed(f);
 
   if (f->pop3_msg_tab == NULL)
     return NULL;
 
-  return mailpop3_msg_info_tab_find_msg(f->pop3_msg_tab, index);
+  return mailpop3_msg_info_tab_find_msg(f->pop3_msg_tab, indx);
 }
 
 
@@ -719,7 +719,7 @@ mailpop3_get_content(mailpop3 * f, struct mailpop3_msg_info * msginfo,
   }
 }
 
-int mailpop3_retr(mailpop3 * f, unsigned int index, char ** result,
+int mailpop3_retr(mailpop3 * f, unsigned int indx, char ** result,
 		  size_t * result_len)
 {
   char command[POP3_STRING_SIZE];
@@ -729,14 +729,14 @@ int mailpop3_retr(mailpop3 * f, unsigned int index, char ** result,
   if (f->pop3_state != POP3_STATE_TRANSACTION)
     return MAILPOP3_ERROR_BAD_STATE;
 
-  msginfo = find_msg(f, index);
+  msginfo = find_msg(f, indx);
 
   if (msginfo == NULL) {
     f->pop3_response = NULL;
     return MAILPOP3_ERROR_NO_SUCH_MESSAGE;
   }
 
-  snprintf(command, POP3_STRING_SIZE, "RETR %i\r\n", index);
+  snprintf(command, POP3_STRING_SIZE, "RETR %i\r\n", indx);
   r = send_command(f, command);
   if (r == -1)
     return MAILPOP3_ERROR_STREAM;
@@ -744,7 +744,7 @@ int mailpop3_retr(mailpop3 * f, unsigned int index, char ** result,
   return mailpop3_get_content(f, msginfo, result, result_len);
 }
 
-int mailpop3_top(mailpop3 * f, unsigned int index,
+int mailpop3_top(mailpop3 * f, unsigned int indx,
     unsigned int count, char ** result,
     size_t * result_len)
 {
@@ -755,14 +755,14 @@ int mailpop3_top(mailpop3 * f, unsigned int index,
   if (f->pop3_state != POP3_STATE_TRANSACTION)
     return MAILPOP3_ERROR_BAD_STATE;
 
-  msginfo = find_msg(f, index);
+  msginfo = find_msg(f, indx);
 
   if (msginfo == NULL) {
     f->pop3_response = NULL;
     return MAILPOP3_ERROR_NO_SUCH_MESSAGE;
   }
 
-  snprintf(command, POP3_STRING_SIZE, "TOP %i %i\r\n", index, count);
+  snprintf(command, POP3_STRING_SIZE, "TOP %i %i\r\n", indx, count);
   r = send_command(f, command);
   if (r == -1)
     return MAILPOP3_ERROR_STREAM;
@@ -770,7 +770,7 @@ int mailpop3_top(mailpop3 * f, unsigned int index,
   return mailpop3_get_content(f, msginfo, result, result_len);
 }
 
-int mailpop3_dele(mailpop3 * f, unsigned int index)
+int mailpop3_dele(mailpop3 * f, unsigned int indx)
 {
   char command[POP3_STRING_SIZE];
   struct mailpop3_msg_info * msginfo;
@@ -780,14 +780,14 @@ int mailpop3_dele(mailpop3 * f, unsigned int index)
   if (f->pop3_state != POP3_STATE_TRANSACTION)
     return MAILPOP3_ERROR_BAD_STATE;
 
-  msginfo = find_msg(f, index);
+  msginfo = find_msg(f, indx);
 
   if (msginfo == NULL) {
     f->pop3_response = NULL;
     return MAILPOP3_ERROR_NO_SUCH_MESSAGE;
   }
 
-  snprintf(command, POP3_STRING_SIZE, "DELE %i\r\n", index);
+  snprintf(command, POP3_STRING_SIZE, "DELE %i\r\n", indx);
   r = send_command(f, command);
   if (r == -1)
     return MAILPOP3_ERROR_STREAM;
@@ -1066,7 +1066,7 @@ static int parse_auth(mailpop3 * f, char * response)
 
 static int read_list(mailpop3 * f, carray ** result)
 {
-  unsigned int index;
+  unsigned int indx;
   uint32_t size;
   carray * msg_tab;
   struct mailpop3_msg_info * msg;
@@ -1084,26 +1084,26 @@ static int read_list(mailpop3 * f, carray ** result)
     if (mailstream_is_end_multiline(line))
       break;
 
-    index = strtol(line, &line, 10);
+    indx = strtol(line, &line, 10);
 
     if (!parse_space(&line))
       continue;
 
     size = strtol(line, &line, 10);
     
-    msg = mailpop3_msg_info_new(index, size, NULL);
+    msg = mailpop3_msg_info_new(indx, size, NULL);
     if (msg == NULL)
       goto free_list;
 
-    if (carray_count(msg_tab) < index) {
+    if (carray_count(msg_tab) < indx) {
       int r;
 
-      r = carray_set_size(msg_tab, index);
+      r = carray_set_size(msg_tab, indx);
       if (r == -1)
 	goto free_list;
     }
 
-    carray_set(msg_tab, index - 1, msg);
+    carray_set(msg_tab, indx - 1, msg);
   }
 
   * result = msg_tab;
@@ -1120,7 +1120,7 @@ static int read_list(mailpop3 * f, carray ** result)
 
 static int read_uidl(mailpop3 * f, carray * msg_tab)
 {
-  unsigned int index;
+  unsigned int indx;
   struct mailpop3_msg_info * msg;
   char * line;
 
@@ -1134,7 +1134,7 @@ static int read_uidl(mailpop3 * f, carray * msg_tab)
     if (mailstream_is_end_multiline(line))
       break;
     
-    index = strtol(line, &line, 10);
+    indx = strtol(line, &line, 10);
 
     if (!parse_space(&line))
       continue;
@@ -1143,12 +1143,12 @@ static int read_uidl(mailpop3 * f, carray * msg_tab)
     if (uidl == NULL)
       continue;
 
-    if (index > carray_count(msg_tab)) {
+    if (indx > carray_count(msg_tab)) {
       free(uidl);
       continue;
     }
 
-    msg = carray_get(msg_tab, index - 1);
+    msg = carray_get(msg_tab, indx - 1);
     if (msg == NULL) {
       free(uidl);
       continue;
@@ -1441,6 +1441,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
     r = parse_auth(f, response);
     switch (r) {
     case RESPONSE_OK:
+      f->pop3_state = POP3_STATE_TRANSACTION;
       res = MAILPOP3_NO_ERROR;
       goto free_sasl_conn;
       
@@ -1528,6 +1529,7 @@ int mailpop3_auth(mailpop3 * f, const char * auth_type,
     }
   }
 
+  f->pop3_state = POP3_STATE_TRANSACTION;
   res = MAILPOP3_NO_ERROR;
   
  free_sasl_conn:
