@@ -11,7 +11,7 @@ enum {
   MBOX_STORAGE,
   MH_STORAGE,
   MAILDIR_STORAGE,
-  FEED_STORAGE,
+  FEED_STORAGE
 };
 
 int parse_options(int argc, char ** argv,
